@@ -14,14 +14,9 @@
 #' as an assymetric similarity measure (i.e. in which the sum of terms in dtm_y is not used). 
 #' 
 #' To emphasize that this feature preparation step is geared towards the task of 'looking up' documents,
-#' we use the terminolog of a 'query'. The output of the function is a list of two dtm: query_dtm and ref_dtm.
+#' we use the terminology of a 'query'. The output of the function is a list of two dtm: query_dtm and ref_dtm.
 #' Both dtms have the exact same columns that contain the query terms.
 #' The values in query_dtm are by default tfidf weighted, and the values in ref_dtm are binary.
-#' 
-#' The special `query_lookup` measure in the \code{\link{compare_documents}} function can be used to
-#' perform the lookup. Note that a more common approach is to weigh both the queries and documents and then match queries to documents
-#' with cosine similarity. However, for event matching we only want to see whether a query 'suffiently' matches a
-#' document. The query_lookup function calculates a query->document weight as the sum of query terms that occur in the document.
 #'  
 #' Several options are given to only create term combinations that are informative. Firstly, a minimum and maximum document frequency of term combinations can be defined. 
 #' Secondly, a minimum observed/expected ratio can be given. The expected probability of a combination of term A and term B
@@ -33,17 +28,14 @@
 #' @param ref_dtm      Optionally, another quanteda \link[quanteda]{dfm}. If given, the ref_dtm will be used to calculate the docfreq/docprob scores.
 #' @param min_docfreq  The minimum frequency for terms or combinations of terms
 #' @param max_docprob  The maximum probability (document frequency / N) for terms or combinations of terms
-#' @param weight       Determine how to weight the queries (if ref_dtm is used, uses the idf of the ref_dtm). 
+#' @param weight       Determine how to weight the queries (if ref_dtm is used, uses the idf of the ref_dtm, or of both the dtm and ref dtm if use_dtm_and_ref is T). 
 #'                     Default is "binary" (does/does not occur). "tfidf" uses common tf-idf weighting (actually just idf, since scores are binary). 
-#'                     The ref_dfm will always be binary. "tfidf_sq" uses the squared tfidf. This weight even heavier by idf, and makes sense because 
-#'                     the query_lookup function will only count the occurences in query_dfm (if both the query_dfm and ref_dfm would be weighted and a crossprod
-#'                     based similarity measure is used, terms are also multiplied) 
 #' @param norm_weight  Normalize the weight score so that the highest value is 1. If "max" is used, max is the highest possible value. "doc_max" uses the highest value within each document, and "dtm_max" uses the highest observed value in the dtm.
 #' @param min_obs_exp  The minimum ratio of the observed and expected frequency of a term combination
 #' @param union_sim_thres If given, a number between 0 and 1, used as the cosine similarity threshold for combining clusters of terms 
 #' @param combine_all  If True, combine all terms. If False (default), terms that are included as unigrams (i.e. that are within the min_docfreq and max_docprob) are not combined with other terms.
 #' @param only_dtm_combs Only include term combinations that occur in dtm. This makes sense (and saves a lot of memory) if you are only interested in assymetric similarity measures based on the query
-#' @param use_dtm_and_ref if a ref_dtm is used, both the dtm and ref_dtm are used to compute the docfreq and docprob values used for filtering and weighting. If use_dtm_and_ref is set o FALSE, only the ref_dtm is used.
+#' @param use_dtm_and_ref if a ref_dtm is used, the weight is computed based only on the document frequencies in the ref dtm. If use_dtm_and_ref is set to TRUE, both the dtm and ref_dtm are used.
 #' @param verbose      If true, report progress
 #'
 #' @return a list with a query dtm and ref_dtm. Designed for use in \code{\link{compare_documents}} using the special `query_lookup` measure
@@ -53,7 +45,7 @@
 #'  q = create_queries(rnewsflow_dfm, min_docfreq = 2, union_sim_thres = 0.9, 
 #'                     max_docprob = 0.05, verbose = FALSE)
 #'  head(colnames(q$query_dtm),100)
-create_queries <- function(dtm, ref_dtm=NULL, min_docfreq=2, max_docprob=0.01, weight=c('tfidf','tfidf_sq', 'binary'), norm_weight=c('max','doc_max','dtm_max','none'), min_obs_exp=NA, union_sim_thres=NA, combine_all=T, only_dtm_combs=T, use_dtm_and_ref=T, verbose=F) {
+create_queries <- function(dtm, ref_dtm=NULL, min_docfreq=2, max_docprob=0.01, weight=c('tfidf', 'binary'), norm_weight=c('max','doc_max','dtm_max','none'), min_obs_exp=NA, union_sim_thres=NA, combine_all=T, only_dtm_combs=T, use_dtm_and_ref=F, verbose=F) {
   weight = match.arg(weight)
   norm_weight = match.arg(norm_weight)
   if (!methods::is(dtm, 'dfm')) stop('dtm has to be a quanteda dfm')
@@ -119,17 +111,21 @@ create_queries <- function(dtm, ref_dtm=NULL, min_docfreq=2, max_docprob=0.01, w
     m_ref = NULL
   }
    
-  if (!ncol(m) == 0) m = weight_queries(m, m_ref, weight, norm_weight)
+  if (!ncol(m) == 0){
+    m = weight_queries(m, m_ref, weight, norm_weight)
+    if (!is.null(m_ref))
+      m_ref = weight_queries(m_ref, m_ref, weight, norm_weight)
+  }
 
   m = quanteda::as.dfm(m)
   quanteda::docvars(m) = quanteda::docvars(dtm)
   
   if (!is.null(m_ref)) {
     if (use_dtm_and_ref) m_ref = m_ref[orig_ref,]   ## remove dtm rows
-    m_ref = quanteda::as.dfm(m_ref > 0)
+    m_ref = quanteda::as.dfm(m_ref)
     quanteda::docvars(m_ref) = quanteda::docvars(ref_dtm)
   } else {
-    m_ref = m > 0
+    m_ref = m
   }
   
   l = list(query_dtm=m, ref_dtm=m_ref)
@@ -206,7 +202,7 @@ term_union <- function(dtm, simmat, as_dfm=T, verbose=F, sep='|', par=NA) {
   ml = term_union_cpp(dtm, simmat, colnames(dtm), parentheses, verbose, sep)
   colnames(ml$m) = ml$colnames
   rownames(ml$m) = rownames(dtm)
-  ml$m = ml$m[,colSums(ml$m) > 0]
+  ml$m = ml$m[,Matrix::colSums(ml$m) > 0]
   
   if (as_dfm && methods::is(dtm, 'dfm')) {
     m = quanteda::as.dfm(ml$m > 0)
@@ -384,7 +380,7 @@ get_doc_terms <- function(dtm, docname=NULL, doc_i=NULL) {
   if (!is.null(doc_i)) docname = quanteda::docnames(dtm)[doc_i]
   r = dtm[quanteda::docnames(dtm) == docname,]
   if (nrow(r) == 0) stop('docname is not a document in dtm')
-  cs = colSums(r)
+  cs = Matrix::colSums(r)
   cs[cs > 0]
 }
 
